@@ -18,7 +18,6 @@ dlcompare <- structure(function # Direct label comparison plot
  debug=FALSE
 ### Show debug output?
  ){
-  require(grid)
   ## Augment positioning method list names if possible
   names(pos.funs) <- sapply(seq_along(pos.funs),function(i){
     N <- names(pos.funs)[i]
@@ -70,20 +69,27 @@ dlcompare <- structure(function # Direct label comparison plot
   popViewport()
 },ex=function(){
   library(lattice)
-  library(ggplot2)
   oldopt <- lattice.options(panel.error=NULL)
 
   ## Compare two plots of the same data using lattice and ggplot2.
-  dts <- cbind(male=mdeaths,female=fdeaths,time=1:length(mdeaths))
-  require(reshape2)
-  ddf <- melt(as.data.frame(dts),id="time")
-  names(ddf) <- c("time","sex","deaths")
-  plots <- list(lattice=
-                xyplot(deaths~time,ddf,groups=sex,type="l",xlim=c(-15,80)),
-                ggplot2=
-                qplot(time,deaths,data=ddf,colour=sex,geom="line")+xlim(-10,80))
+  deaths.by.sex <- list(male=mdeaths, female=fdeaths)
+  deaths.list <- list()
+  for(sex in names(deaths.by.sex)){
+    deaths.ts <- deaths.by.sex[[sex]]
+    deaths.list[[sex]] <-
+      data.frame(year=as.numeric(time(deaths.ts)),
+                 sex,
+                 deaths=as.integer(deaths.ts))
+  }
+  deaths <- do.call(rbind, deaths.list)
+  death.plot.list <-
+    list(lattice=xyplot(deaths~year,deaths,groups=sex,type="l"))
+  if(require(ggplot2)){
+    death.plot.list$ggplot2 <- 
+      qplot(year,deaths,data=deaths,colour=sex,geom="line")
+  }
 
-  if(names(dev.cur())!="postscript"){##to avoid error on pkg check Try
+  if(names(dev.cur())!="postscript"){##to avoid error on pkg check.
     ## Use some exotic labeling options with different rotation, font
     ## face, family, and alpha transparency.
     exotic <- list("last.points",
@@ -92,15 +98,17 @@ dlcompare <- structure(function # Direct label comparison plot
                    fontface=c("bold","italic"),
                    fontfamily=c("mono","serif"),
                    alpha=c(0.25,1))
-    dlcompare(plots,list(exotic))
+    dlcompare(death.plot.list, list(exotic))
   }
+    
+  lattice.options(oldopt)
 
   ## Compare a legend with direct labels on the same plot.
   library(nlme)
-  ggrat <- qplot(Time,weight,data=BodyWeight,
-                 colour=Rat,geom="line",facets=.~Diet)
-  pfuns <- list("legend","direct labels"="last.qp")
-  dlcompare(list(ggrat),pfuns,rects=FALSE,row.items="posfuns")
-  
-  lattice.options(oldopt)
+  if(require(ggplot2)){
+    ggrat <- qplot(Time,weight,data=BodyWeight,
+                   colour=Rat,geom="line",facets=.~Diet)
+    pfuns <- list("legend","direct labels"="last.qp")
+    dlcompare(list(ggrat),pfuns,rects=FALSE,row.items="posfuns")
+  }
 })
