@@ -8,7 +8,7 @@ uselegend.trellis <- function
   if(is.null(p$legend))update(p,auto.key=TRUE)
   else p
 }
- 
+
 ### Some lattice plot functions do some magic in the background to
 ### translate the data you give them into the data points that are
 ### plotted onscreen. We have to replicate this magic in native
@@ -19,13 +19,13 @@ lattice.translators <- list(qqmath=function(d,distribution,f.value,qtype=7,...){
   ## from panel.qqmath. (total hack)
   gapply(d,function(d,...){
     x <- as.numeric(d$x)
-    distribution <- if (is.function(distribution)) 
+    distribution <- if (is.function(distribution))
       distribution
-    else if (is.character(distribution)) 
+    else if (is.character(distribution))
       get(distribution)
     else eval(distribution)
     nobs <- sum(!is.na(x))
-    if (is.null(f.value)) 
+    if (is.null(f.value))
       data.frame(x = distribution(ppoints(nobs)), y = sort(x))
     else data.frame(x = distribution(
                       if (is.numeric(f.value))f.value
@@ -49,7 +49,8 @@ direct.label.trellis <- function
 ### The lattice plot (result of a call to a high-level lattice
 ### function).
  method=NULL,
-### Method for direct labeling as described in ?label.positions.
+### Method for direct labeling as described in
+### \code{\link{apply.method}}.
  debug=FALSE
 ### Show debug output?
  ){
@@ -90,7 +91,7 @@ panel.superpose.dl <- structure(function
  method=NULL,
 ### Positioning Method for direct labeling. NULL indicates to choose a
 ### Positioning Method based on the panel.groups function.
- .panel.superpose=panel.superpose,
+ .panel.superpose=lattice::panel.superpose,
 ### The panel function to use for drawing data points.
  type="p",
 ### Plot type, used for default method dispatch.
@@ -118,8 +119,13 @@ panel.superpose.dl <- structure(function
   type <- type[type!="g"] ## printing the grid twice looks bad.
   col.text <-
     switch(type,p="superpose.symbol",l="superpose.line","superpose.line")
-  tpar <- trellis.par.get()
-  key <- rep(tpar[[col.text]]$col,length.out=nlevels(d$groups))
+  tpar <- lattice::trellis.par.get()
+  col.values <- if("col" %in% names(rgs)){
+    rgs$col
+  }else{
+    tpar[[col.text]]$col
+  }
+  key <- rep(col.values, length.out=nlevels(d$groups))
   names(key) <- levels(d$groups)
   ## maybe eventually allow these to be specified in options()??
   translator <- lattice.translators[[lattice.fun.name]]
@@ -139,7 +145,7 @@ panel.superpose.dl <- structure(function
                      ))
   print(direct.label( ## exactly the same as above but with specific panel fns
                      densityplot(~ppp,loci,groups=type,n=500,
-                                 panel=panel.superpose,
+                                 panel=lattice::panel.superpose,
                                  panel.groups="panel.densityplot")
                      ))
   ## using panel.superpose.dl as the panel function automatically adds
@@ -148,11 +154,11 @@ panel.superpose.dl <- structure(function
                     panel=panel.superpose.dl,panel.groups="panel.densityplot"))
 
   ## Exploring custom panel and panel.groups functions
-  library(ggplot2)
   library(nlme)
   ## Say we want to use a simple linear model to explain rat body weight:
   fit <- lm(weight~Time+Diet+Rat,BodyWeight)
-  bw <- fortify(fit,BodyWeight)
+  bw <- BodyWeight
+  bw$.fitted <- predict(fit,BodyWeight)
   ## lots of examples to come, all with these arguments:
   ratxy <- function(...){
     xyplot(weight~Time|Diet,bw,groups=Rat,type="l",layout=c(3,1),...)
@@ -183,7 +189,7 @@ panel.superpose.dl <- structure(function
     panel.xyplot(x=x,subscripts=subscripts,col.line=col.line,...)
     llines(x,bw[subscripts,".fitted"],col=col.line,lty=2)
   }
-  pg <- ratxy(panel=panel.superpose,panel.groups=panel.model)
+  pg <- ratxy(panel=lattice::panel.superpose,panel.groups=panel.model)
   print(pg)
   ## If you use panel.superpose.dl with a custom panel.groups function,
   ## you need to manually specify the Positioning Method, since the
@@ -193,7 +199,7 @@ panel.superpose.dl <- structure(function
               method="first.qp"))
 
   ## Custom panel function that draws a box around values:
-  panel.line1 <- function(ps=panel.superpose){
+  panel.line1 <- function(ps=lattice::panel.superpose){
     function(y,...){
       panel.abline(h=range(y))
       ps(y=y,...)
@@ -223,13 +229,7 @@ defaultpf.trellis <- function
 ### option to a function like this.
 (lattice.fun.name,groups,type,...){
   ldefault <- function(){
-    if(nlevels(groups)==2)"lines2" else {
-      if(require(quadprog))"maxvar.qp"
-      else {
-        warning("install quadprog package for labels that do not overlap")
-        "maxvar.points"
-      }
-    }
+    if(nlevels(groups)==2)"lines2" else "maxvar.qp"
   }
   lattice.fun.name <-
     switch(lattice.fun.name,
